<?php
/**
 * Storefront template functions.
 *
 * @package storefront-child
 */

/**
* @return render top bar on header area
*/
add_action( 'storefront_before_header', 'hardware_store_add_top_bar', 11 );
function hardware_store_add_top_bar() { ?>
	<div class="col-full sfc-top-header clearfix">
		<div class="sfc-top-left">
			<div class="sfc-top-left-content">
				<ul>
					<?php
						if( function_exists( 'qtranxf_generateLanguageSelectCode' ) ) {
							echo '<li class="language-flag">';
							$args = array( 'type' => 'dropdown' ); 
							qtranxf_generateLanguageSelectCode( $args );
							echo '</li>';
						}
					
					if( get_theme_mod( 'contact_details' ) ) {	?>
						<li class="contact-details">
							<a href="tel:<?php echo esc_attr( get_theme_mod( 'contact_details' ) ); ?>">
								<i class="fa fa-phone" aria-hidden="true"></i> <span>
									<?php echo esc_html( get_theme_mod( 'contact_details' ) ); ?>
								</span>
							</a>
						</li>
					<?php }
						if( get_theme_mod( 'contact_details_email' ) ) { ?>
							<li class="contact-details">
								<a href="mailto:<?php echo sanitize_email( get_theme_mod( 'contact_details_email', 'example@example.com' ) ); ?>">
									<i class="fa fa-envelope-open" aria-hidden="true"></i><span>
										<?php echo sanitize_email( get_theme_mod( 'contact_details_email', 'example@example.com' ) ); ?>
									</span>
								</a>
							</li>
					<?php } ?>
				</ul>
				
			</div>
			
		</div>
		<div class="site-branding sfc-logo">
			<?php storefront_site_title_or_logo(); ?>
		</div>
		<div class="sfc-top-right">
			<?php
				if ( has_nav_menu( 'secondary' ) ) {
				    
				    wp_nav_menu(
					    array(
						    'theme_location'	=> 'secondary',
					    )
				    );

				} 
			?>
		</div>
	</div>
<?php }


/**
* @return add search form to storefront_before_content with priority 11
* @version 1.0.0
*/
add_action( 'homepage', 'hardware_store_add_advance_filter_on_head_section', 11 );
function hardware_store_add_advance_filter_on_head_section() {
	if( storefront_is_woocommerce_activated() ) { ?>
		<div class="col-full">
			<?php woocommerce_breadcrumb(); ?>
		</div>

		<?php if( is_home() || is_shop() || is_front_page() || is_product_category() || is_product_tag() ) {
			get_template_part( 'template/sfc-search-form' );
		}
	}
}

/**
* @return Add roboto google fonts
* @version 1.0.0
*/
add_filter( 'storefront_google_font_families', 'hardware_store_add_google_fonts'  );
function hardware_store_add_google_fonts( $google_fonts = array() ) {

	$google_fonts[ 'roboto'] = 'https://fonts.googleapis.com/css?family=Roboto:100,300,400,500,700,900';
	return $google_fonts;
}

add_action( 'woocommerce_before_shop_loop_item', 'hardware_store_add_div_before_anchor', 1 );
function hardware_store_add_div_before_anchor() {
	echo '<div class="sfc-main-container">';
}
/**
* @return add <div class="sfc-product-data"> before
* the title.
* @version 1.0
*/
add_action( 'woocommerce_before_shop_loop_item_title', 'hardware_store_add_div_before_title', 11 );
function hardware_store_add_div_before_title() {
	echo '<div class="sfc-product-data">';
}

add_action( 'woocommerce_after_shop_loop_item', 'hardware_store_add_div_after_title', 11 );
function hardware_store_add_div_after_title() {
	echo '</div></div>';
}

/**
 * Get the add to cart template for the loop.
 */
function woocommerce_template_loop_add_to_cart( $args = array() ) {

	global $product;

	if ( $product ) {
		$defaults = array(
			'quantity' => 1,
			'class'    => implode( ' ', array_filter( array(
				'button',
				'product_type_' . $product->get_type(),
				$product->is_purchasable() && $product->is_in_stock() ? 'add_to_cart_button' : '',
				$product->supports( 'ajax_add_to_cart' ) ? 'ajax_add_to_cart' : ''
			) ) )
		);

		$args = apply_filters( 'woocommerce_loop_add_to_cart_args', wp_parse_args( $args, $defaults ), $product ); ?>
		<!-- add to cart -->
		<div class="sfc-cart">
			<?php 
				//add cart form
				do_action( 'woocommerce_' . $product->get_type() . '_add_to_cart' ); 
			?>
		</div>
		<!-- ask for quote -->
		<?php 
			if( class_exists( 'YITH_YWRAQ_Frontend'  ) ) { ?>
				<form class="cart sfc-ask-for-quote-cart" method="post" enctype="multipart/form-data">
					
					<div class="sfc-ask-for-quote">
						<div class="quantity">
							<input type="number" step="1" min="1" max="1000" name="quantity" value="1" title="Qty" class="input-text qty text" size="4" pattern="[0-9]*" inputmode="numeric">
						</div>
						<span class="sfc-quote-link clearfix">
							<?php
								$add_to_quote = new YITH_YWRAQ_Frontend();
								$add_to_quote->print_button();
							?>
						</span>
					</div>
				</form>
			<?php }
	}
}


/**
* @return variable data with single attrubutes
* if there is multiple combination attributes this code wouldn't execute
*/
add_action( 'hardware_store_single_attributes', 'hardware_store_single_attributes', 10, 2 );
function hardware_store_single_attributes( $available_variations, $attributes ) { 
	global $product;
	$attribute_keys = array_keys( $attributes ); 
	$attributes_index = 'attribute_'. $attribute_keys[ 0]; ?>
	<div class="sfc-variation-data clearfix">
		<div class="sfc-variable-price-list">
			<ul class="sfc-variable-list-items">
				<?php
					foreach ($available_variations as $key => $data) {
						echo '<li class="sfc-variable-list-item" product-id="'.esc_attr( absint( $product->get_id() )).'" variation-id="'.esc_attr( $data[ 'variation_id' ] ).'" >';
							if( $data[ 'price_html' ] ) {
								echo wp_kses_post( $data[ 'price_html' ] );
							} else {
								echo wp_kses_post( wc_price( $data[ 'display_price' ] ) );
							}
						echo '</li>';
					}
				?>	
			</ul>
		</div>
		<div class="sfc-variable-image-list">
			<ul class="sfc-variable-list-items clearfix">
				<?php
					$image_link = '';
					foreach ( $available_variations as $key => $data ) {
						$product_thumbnail = get_the_post_thumbnail_url( get_the_id() );
						if( ( $product_thumbnail != $data[ 'image' ][ 'url' ] ) && ( ! empty( $data[ 'image' ][ 'url' ] ) ) && ( ! empty( $data[ 'image_id' ] ) ) ) {
							$image_link = $data[ 'image' ][ 'url' ];
						}
						

						echo '<li class="sfc-variable-list-item" attribute_name="'. esc_attr( $attribute_keys[0] ) . '" attribute_value="'.esc_attr( $data[ 'attributes'][ $attributes_index ] ) . '"  product-id="' . absint( $product->get_id() ) . '" variation-id="'. absint( $data[ 'variation_id' ] ).'" >';
								if( $image_link != '' ) {
									echo '<img title="'.esc_attr( $data[ 'attributes'][ $attributes_index ] ).'" src="'. esc_url( $image_link ).'" />';
								} else {
									echo '<p class="sfc-attribute-name">' . esc_attr( $data[ 'attributes'][ $attributes_index ] ) . '</p>';
								}
						echo '</li>';
					}
				?>	
			</ul>
		</div>
	</div>	
	<?php
		$sfc_attribute_name = array(); 
		foreach ( $attributes as $attribute_name => $options ) {
			$sfc_attribute_name[] = $attribute_name;
		}
	?>

	<div class="sfc-variable-cart">
		<form class="cart" method="post" enctype="multipart/form-data">
			<div class="quantity">
				<input type="number" step="1" min="1" max="99" name="quantity" value="1" title="Qty" class="input-text qty text" size="4" pattern="[0-9]*" inputmode="numeric">
			</div>
			<input type="hidden" name="add-to-cart" value="<?php echo absint( $product->get_id() ); ?>">
			<button type="submit" class="single_add_to_cart_button button alt"><?php esc_html_e( 'Add to cart', 'hardware-store' ); ?></button>
			 <input type="hidden" name="product_id" value="<?php echo absint( $product->get_id() ); ?>">
			<input type="hidden" name="variation_id" class="variation_id" value="<?php echo absint( $available_variations[0][ 'variation_id' ] ); ?>">
			<input type="hidden" name="attribute_<?php echo esc_html( $sfc_attribute_name[0] );?>" class="attached enabled" value="<?php echo esc_attr( $available_variations[0][ 'attributes']['attribute_'.$sfc_attribute_name[0] ] ); ?>">
		</form>
	</div>
<?php }

/**
* @return customizer footer credit section
*/
add_action( 'storefront_after_footer', 'hardware_store_add_footer_credit' );
function hardware_store_add_footer_credit() { ?>
	<div class="sfc_site_footer">
		<div class="col-full">
			<div class="site-info clearfix">
				<div class="sfc-footer-social-link">
					<ul class="sfc-social-items clearfix">
						<?php
							$social_network_links = array(
								'linkedin' => 'fa fa-linkedin',
								'facebook' => 'fa fa-facebook',
								'twitter' => 'fa fa-twitter',
								'google_plus' => 'fa fa-google-plus',
							);
							foreach ($social_network_links as $key => $value) {
								if( get_theme_mod($key ) ) {
									echo '<li>
									 <a href="'.esc_url( get_theme_mod( $key ) ).'">
									 	<i class="fa '. esc_attr( $value ).'" aria-hidden="true"></i>
									 </a>
									</li>';
								}
							}
						?>
					</ul>
				</div>
				<div class="sfc-footer-crdit-links">
					<?php 
						printf( esc_attr__( '%1$s designed by %2$s.', 'hardware-store' ), 'HardWare Store', '<a target="_blank" href="https://sushilwp.wordpress.com/sushil-adhikari/" rel="author">Sushil Adhikari</a>' ); 
					?>
				</div>
			</div>
		</div>
	</div>	
<?php }


/**
* @return add ask for quote on single product page
* @version 1.0
*/
function woocommerce_template_single_add_to_cart() {
		global $product;
		echo '<div class="sfc-single-product-add-to-cart sfc-product-data" >';
			do_action( 'woocommerce_' . $product->get_type() . '_add_to_cart' );
			if( class_exists( 'YITH_YWRAQ_Frontend'  ) ) {  ?>
				<form class="cart sfc-ask-for-quote-single-product" method="post" enctype="multipart/form-data">
					<div class="sfc-ask-for-quote">
						<div class="quantity">
							<input type="number" step="1" min="1" max="1000" name="quantity" value="1" title="Qty" class="input-text qty text afq-input-val" size="4" pattern="[0-9]*" inputmode="numeric">
						</div>
						<span class="sfc-quote-link clearfix">
							<?php
								$add_to_quote = new YITH_YWRAQ_Frontend();
								$add_to_quote->print_button();
							?>
						</span>
					</div>
				</form>
			<?php } ?>
		</div>
<?php }

/**
* @return remove do_action( 'storefront_sidebar' ); from single product page
* @since 1.0
*/
function storefront_after_content() { ?>
		</main><!-- #main -->
	</div><!-- #primary -->

<?php }

/**
* @return at the <div class="sfc-top-banner"> top of sale flash
*/
add_action( 'woocommerce_before_single_product_summary', 'hardware_store_product_banner_div', 8 );
function hardware_store_product_banner_div() { ?>
	<div class="sfc-single-product-top-banner clearfix">
		<div class="sfc-left-banner-content col-md-9 col-xs-12 col-sm-9 clearfix">
<?php }

/*
*/
add_action( 'woocommerce_after_single_product_summary', 'hardware_store_product_banner_close_div', 5 );
function hardware_store_product_banner_close_div() { ?>
		</div><!-- .sfc-left-banner-content -->
		<div class="sfc-top-right-banner-content col-md-3 col-sm-3 col-xs-12">
			<?php get_sidebar( 'product-banner' ); ?>
		</div>
		
	</div><!-- .sfc-single-product-top-banner -->


<?php }


/**
* @return display shop sidebar on archive pages
*/
add_action( 'woocommerce_sidebar', 'hardware_store_archive_sidebar', 10 );
function hardware_store_archive_sidebar() {
	if( ! is_product() ) :
		get_sidebar( 'shop' );
	else :
		return;
	endif;
}

/**
* @return remove woocommerce header from archive pages
*/
add_filter( 'woocommerce_show_page_title', 'hardware_store_remove_woocommerce_header' );
function hardware_store_remove_woocommerce_header() {
	return false;
}

/**
* @return Remove ask to quote button from single page
*/
add_filter( 'yith_ywraq-show_btn_single_page', 'hardware_store_remove_add_to_quote_from_signle_page' );
function hardware_store_remove_add_to_quote_from_signle_page() {
	return false;
}

/**
* @return add field on ask for quote checkout
*/
add_action( 'ywraq_process', 'hardware_store_add_field_value' );
function hardware_store_add_field_value( $args = array() ) {
	$args[ 'user_company' ] = sanitize_text_field( $_POST[ 'rqa_phonenumber' ] );
	$args[ 'user_company' ] = sanitize_text_field( $_POST[ 'rqa_company' ] );
	return $args;
}



add_filter('wp_nav_menu_items','hardware_store_add_woocommerce_login_register_link', 10, 2 );

if( ! function_exists( 'hardware_store_add_woocommerce_login_register_link' ) ) :
/**
* @return This adds header card on to the secondary menu
* @version 1.0.0
*/

function hardware_store_add_woocommerce_login_register_link( $items, $args ) {
	if( ! storefront_is_woocommerce_activated()  ) return $items;
	$woocommerce_login_html = '';
	if( $args->theme_location == 'secondary' ) {
	
		if ( is_user_logged_in() ) {
		 	$woocommerce_login_html = '<li class="sfc-myaccount"><a href="'.esc_url( get_permalink( get_option('woocommerce_myaccount_page_id' ) ) ).'" title="'.__('My Account','hardware-store').'">'. __( 'My Account','hardware-store').'</a></li>';
		} else {
		 	$woocommerce_login_html = '<li class="sfc-myaccount"><a href="'.esc_url( get_permalink( get_option('woocommerce_myaccount_page_id') ) ).'" title="'.__('Login','hardware-store').'">'.__( 'Login', 'hardware-store' ).'</a></li>';
		}

		if(  function_exists( 'storefront_header_cart') ) {
			ob_start();
				storefront_header_cart();
				$output = ob_get_contents();
			ob_end_clean();
			$woocommerce_login_html .= '<li class="sfc-top-bar-cart">'. $output.'</li>';
		}



	}

	return $items.$woocommerce_login_html;
}
endif;


add_filter( 'storefront_related_products_args', 'hardware_store_change_related_product_args' );
function hardware_store_change_related_product_args( $args ) {
	$paged = ( get_query_var( 'paged' ) ) ? get_query_var( 'paged' ) : 1;
	$args[ 'columns'] = 4;
	$args[ 'posts_per_page' ] = -1;
	$args[ 'paged' ] = $paged;
	return $args;
}

/**
* @return woof use choosen
*/
function storefront_is_woof_use_chosen() {
	$is = get_option('use_chosen', 1);
	$is = apply_filters('woof_use_chosen', $is);
	return $is;
}

function storefront_product_search() {
	if ( storefront_is_woocommerce_activated() ) { ?>
		<div class="site-search">
			<?php get_template_part( 'template/sfc-search-form' ); ?>
		</div>
	<?php }
}

add_filter( 'storefront_setting_default_values', 'hardware_store_change_customizer_default_value' );
function hardware_store_change_customizer_default_value( $args = array() ) {
	$args[ 'storefront_header_background_color' ] = '#0073aa';
	$args[ 'storefront_button_background_color' ] = '#0073aa';
	$args[ 'storefront_button_alt_background_color' ] = '#0073aa';
	$args[ 'storefront_button_text_color' ] = '#fff';
	return $args;
}

/**
 * Override theme default specification for product # per row
 */
function hardware_store_change_loop_column() {
	return 3; // 5 products per row
}
add_filter('loop_shop_columns', 'hardware_store_change_loop_column', 999);


/**
* @return array 
* @param array $args
*/
add_filter( 'storefront_featured_products_args', 'hardware_store_change_widget_column' );
add_filter( 'storefront_popular_products_args', 'hardware_store_change_widget_column' );
add_filter( 'storefront_on_sale_products_args', 'hardware_store_change_widget_column' );
add_filter( 'storefront_best_selling_products_args', 'hardware_store_change_widget_column' );
add_filter( 'storefront_recent_products_args', 'hardware_store_change_widget_column' );
add_filter( 'storefront_product_categories_args', 'hardware_store_change_widget_column' );
function hardware_store_change_widget_column( $args ) {
	if( isset( $args[ 'columns' ] ) ) {
		$args[ 'columns' ] = 3;
	}

	if( isset( $args[ 'limit' ] ) ) {
		$args[ 'columns' ] = 3;
	}
	return $args;
}

/**
* @param array $args
* @return array $args
*/
add_filter( 'woocommerce_output_related_products_args', 'hardware_store_related_products_args', 20 );
function hardware_store_related_products_args( $args ) {
	$args['posts_per_page'] = 4; // 4 related products
	$args['columns'] = 2; // arranged in 2 columns
	return $args;
}